pub struct ServiceRef { /* private fields */ }Expand description
Struct to hold a published service, which keeps the service alive while a reference to it is held. When dropped the Service will be removed and any associated resources deallocated.
This should be created via a Service or a
ServiceResolver. For a browse
operation the ServiceRef is held by the ServiceBrowser created by a
ServiceBrowserBuilder.
Implementations