pub trait ProcessTask:
Future<Output = ()>
+ Send
+ Sync { }Expand description
The ProcessTask trait represents the future that is returned from some
functions that is awaited on to process events associated with a published
service or a browse operation.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".